cdf_order_r: R function that calculates the probability of r-th order...

View source: R/Orderstatistics.R

cdf_order_rR Documentation

R function that calculates the probability of r-th order statistics of normal random variables (CDF of r-th order statistics)

Description

R function that calculates the probability of r-th order statistics of normal random variables (CDF of r-th order statistics)

Usage

cdf_order_r(x, r, distribution, arg1, arg2)

Arguments

x

the value of x

r

r-th order statistics

distribution

the distribution of marker value follows Normal or Gamma

arg1

if distribution is normal input mean parameters of all subclasses in a vector, if gamma input shape parameters

arg2

if distribution is normal input variance parameter, if gamma input rate parameters

Value

The probability of r-th order statistics of random variables smaller or equal to x


CompClassMetrics documentation built on Feb. 28, 2026, 1:07 a.m.