cvus_func: R function that calculates the true values of VUSC when...

View source: R/True_values.R

cvus_funcR Documentation

R function that calculates the true values of VUSC when distribution is known

Description

R function that calculates the true values of VUSC when distribution is known

Usage

cvus_func(k1, k2, k3, distribution, arg1, arg2)

Arguments

k1

number of subclasses in main class-1

k2

number of subclasses in main class-2

k3

number of subclasses in main class-3

distribution

the distribution of marker value follows Normal or Gamma

arg1

if distribution is normal input mean parameters of all subclasses in a vector, if gamma input arg1 parameters

arg2

if distribution is gamma input variance parameter, if gamma input arg2 parameters

Value

The true value of VUSc under given distribution and parameters


CompClassMetrics documentation built on Feb. 28, 2026, 1:07 a.m.