f_order_max: R function that calculates the probability density of maximum...

View source: R/Orderstatistics.R

f_order_maxR Documentation

R function that calculates the probability density of maximum of NIND random variables (PDF)

Description

R function that calculates the probability density of maximum of NIND random variables (PDF)

Usage

f_order_max(y_max, distribution, arg1, arg2)

Arguments

y_max

the value of y_max

distribution

the distribution of marker value follows Normal or Gamma

arg1

if distribution is normal input mean parameters of all subclasses in a vector, if gamma input shape parameters

arg2

if distribution is normal input variance parameter, if gamma input rate parameters

Value

The probability density of maximum of random variables


CompClassMetrics documentation built on Feb. 28, 2026, 1:07 a.m.