humc_fourclass: R function that calculates the true values of HUMcm when...

View source: R/True_values.R

humc_fourclassR Documentation

R function that calculates the true values of HUMcm when distribution is known

Description

R function that calculates the true values of HUMcm when distribution is known

Usage

humc_fourclass(distribution, arg1, arg2, num_sub)

Arguments

distribution

the distribution of marker value follows Normal or Gamma

arg1

if distribution is normal input mean parameters of all subclasses in a vector, if gamma input arg1 parameters

arg2

if distribution is gamma input variance parameter, if gamma input arg2 parameters

num_sub

the vector of number of subclasses in each main class

Value

The true value of HUMcm under given distribution and parameters


CompClassMetrics documentation built on Feb. 28, 2026, 1:07 a.m.