| rocc_curve_emp | R Documentation |
R function for plotting the empirical compound ROC curve and chance curve
rocc_curve_emp(dat, num_sub)
dat |
values in list, each element represents biomarker values for a disease group, ordered in ascending severity |
num_sub |
a vector of number of subclasses in each subclass |
The empirical compound ROC curve and chance curve
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.