rocc_surface_emp: R function for plotting the empirical compound ROC surface...

View source: R/Plots2.R

rocc_surface_empR Documentation

R function for plotting the empirical compound ROC surface and chance surface

Description

R function for plotting the empirical compound ROC surface and chance surface

Usage

rocc_surface_emp(dat, num_sub)

Arguments

dat

values in list, each element represents biomarker values for a disease group, ordered in ascending severity

num_sub

a vector of number of subclasses in each subclass

Value

The empirical compound ROC surface and chance surface


CompClassMetrics documentation built on Feb. 28, 2026, 1:07 a.m.