| auco_func | R Documentation |
R function that calculates the true values of AUCo when distribution is known
auco_func(k1, k2, distribution, arg1, arg2)
k1 |
number of subclasses in main class-1 |
k2 |
number of subclasses in main class-2 |
distribution |
the distribution of marker value follows Normal or Gamma |
arg1 |
if distribution is normal input mean parameters of all subclasses in a vector, if gamma input arg1 parameters |
arg2 |
if distribution is gamma input variance parameter, if gamma input arg2 parameters |
The true value of AUCo under given distribution and parameters
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.