View source: R/Orderstatistics.R
| cdf_min_max_partial | R Documentation |
R function that calculates the partial of joint probability of min and max over max of NIND random variables
cdf_min_max_partial(y_min, y_max, distribution, arg1, arg2)
y_min |
the value of y_min |
y_max |
the value of y_max |
distribution |
the distribution of marker value follows Normal or Gamma |
arg1 |
if distribution is normal input mean parameters of all subclasses in a vector, if gamma input shape parameters |
arg2 |
if distribution is normal input variance parameter, if gamma input rate parameters |
The partial of joint probablity of min and max over max
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.