View source: R/Orderstatistics.R
| cdf_order_r | R Documentation |
R function that calculates the probability of r-th order statistics of normal random variables (CDF of r-th order statistics)
cdf_order_r(x, r, distribution, arg1, arg2)
x |
the value of x |
r |
r-th order statistics |
distribution |
the distribution of marker value follows Normal or Gamma |
arg1 |
if distribution is normal input mean parameters of all subclasses in a vector, if gamma input shape parameters |
arg2 |
if distribution is normal input variance parameter, if gamma input rate parameters |
The probability of r-th order statistics of random variables smaller or equal to x
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.