View source: R/Orderstatistics.R
| f_order_max | R Documentation |
R function that calculates the probability density of maximum of NIND random variables (PDF)
f_order_max(y_max, distribution, arg1, arg2)
y_max |
the value of y_max |
distribution |
the distribution of marker value follows Normal or Gamma |
arg1 |
if distribution is normal input mean parameters of all subclasses in a vector, if gamma input shape parameters |
arg2 |
if distribution is normal input variance parameter, if gamma input rate parameters |
The probability density of maximum of random variables
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.